==> trilinos_10.0.4.dfsg.orig.tar.gz: trilinos-10.0.4.dfsg.orig/packages/Sundance/src-solvers/Operators/TSFSimpleAddedOpDecl.hpp <==
/* @HEADER@ */
/* ***********************************************************************
// 
//           TSFExtended: Trilinos Solver Framework Extended
//                 Copyright (2004) Sandia Corporation
// 
// Under terms of Contract DE-AC04-94AL85000, there is a non-exclusive
// license for use of this work by or on behalf of the U.S. Government.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//  
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA
// Questions? Contact Michael A. Heroux (maherou@sandia.gov) 
// 
// **********************************************************************/
/* @HEADER@ */

#ifndef TSF_SIMPLE_ADDED_OP_DECL_HPP
#define TSF_SIMPLE_ADDED_OP_DECL_HPP



#include "SundanceDefs.hpp"
#include "TSFSimplifiedLinearOpBaseDecl.hpp"
#include "TSFLinearOperatorDecl.hpp"


namespace TSFExtended
{
using namespace Teuchos;
using namespace SundanceUtils;
using std::endl;


/**
 * Represent a sum of operators A_0 + A_1 + ... + A_n.
 */
template <class Scalar>
class SimpleAddedOp : public SimplifiedLinearOpWithSpaces<Scalar>
{
public:
  /** */
  SimpleAddedOp(const Array<LinearOperator<Scalar> >& ops);

  /** */
  void applyOp(const Thyra::ETransp M_trans,
    const Vector<Scalar>& in,
    Vector<Scalar> out) const;
  
  /** */
  std::string description() const ;

private:
    Array<LinearOperator<Scalar> > ops_;
};

/** \relates LinearOperator */
template <class Scalar>
LinearOperator<Scalar> addedOperator(
  const Array<LinearOperator<Scalar> >& ops);


/** \relates LinearOperator */
template <class Scalar> 
LinearOperator<Scalar> 
operator+(const LinearOperator<Scalar>& A,
  const LinearOperator<Scalar>& B);


}

#endif

==> trilinos_10.4.0.dfsg.orig.tar.gz: trilinos-10.4.0.dfsg.orig/packages/Sundance/src-solvers/Operators/TSFSimpleAddedOpDecl.hpp <==
/* @HEADER@ */
/* ***********************************************************************
// 
//           TSFExtended: Trilinos Solver Framework Extended
//                 Copyright (2004) Sandia Corporation
// 
// Under terms of Contract DE-AC04-94AL85000, there is a non-exclusive
// license for use of this work by or on behalf of the U.S. Government.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//  
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA
// Questions? Contact Michael A. Heroux (maherou@sandia.gov) 
// 
// **********************************************************************/
/* @HEADER@ */

#ifndef TSF_SIMPLE_ADDED_OP_DECL_HPP
#define TSF_SIMPLE_ADDED_OP_DECL_HPP



#include "SundanceDefs.hpp"
#include "TSFSimplifiedLinearOpBaseDecl.hpp"
#include "TSFLinearOperatorDecl.hpp"


namespace TSFExtended
{
using namespace Teuchos;
using namespace Sundance;
using std::endl;


/**
 * Represent a sum of operators A_0 + A_1 + ... + A_n.
 */
template <class Scalar>
class SimpleAddedOp : public SimplifiedLinearOpWithSpaces<Scalar>
{
public:
  /** */
  SimpleAddedOp(const Array<LinearOperator<Scalar> >& ops);

  /** */
  void applyOp(const Thyra::EOpTransp M_trans,
    const Vector<Scalar>& in,
    Vector<Scalar> out) const;
  
  /** */
  std::string description() const ;

private:
    Array<LinearOperator<Scalar> > ops_;
};

/** \relates LinearOperator */
template <class Scalar>
LinearOperator<Scalar> addedOperator(
  const Array<LinearOperator<Scalar> >& ops);


/** \relates LinearOperator */
template <class Scalar> 
LinearOperator<Scalar> 
operator+(const LinearOperator<Scalar>& A,
  const LinearOperator<Scalar>& B);


}

#endif
